@@ -24,6 +24,7 @@
 *
 *****************************************************************************/
 
+#define _FILE_OFFSET_BITS 64
 #include <sys/mman.h>
 #include <unistd.h>
 
@@ -195,7 +196,7 @@ void send_dec_inputbuf_orphan_msg(v4l2_daemon_inst *h, vsi_v4l2_msg *v4l2_msg,
  * @param int32_t error, error id.
  * @return void.
  */
-void send_fatalerror_orphan_msg(unsigned long inst_id, int32_t error) {
+void send_fatalerror_orphan_msg(uint64_t inst_id, int32_t error) {
   vsi_v4l2_msg msg = {0};
 
   msg.inst_id = inst_id;
@@ -214,7 +215,7 @@ void send_fatalerror_orphan_msg(unsigned long inst_id, int32_t error) {
  * @param int32_t warn_id, warning id.
  * @return void.
  */
-void send_warning_orphan_msg(unsigned long inst_id, int32_t warn_id)
+void send_warning_orphan_msg(uint64_t inst_id, int32_t warn_id)
 {
   vsi_v4l2_msg msg = {0};
 
@@ -234,7 +235,7 @@ void send_warning_orphan_msg(unsigned long inst_id, int32_t warn_id)
  * @param int32_t cmd_id, message id.
  * @return void.
  */
-void send_cmd_orphan_msg(unsigned long inst_id, int32_t cmd_id)
+void send_cmd_orphan_msg(uint64_t inst_id, int32_t cmd_id)
 {
   vsi_v4l2_msg msg = {0};
 
@@ -317,20 +318,19 @@ int32_t open_mmap_device_daemon() {
  */
 uint32_t *mmap_phy_addr_daemon(int32_t fd, vpu_addr_t phy_addr, int32_t size) {
   void *v_addr; /* virtual addr */
-  vpu_addr_t aligned_phy_addr = phy_addr & (~(MEM_PAGE_SIZE - 1));
+  off_t aligned_phy_addr = (off_t)(phy_addr & (~(sysconf(_SC_PAGE_SIZE) - 1)));
   uint32_t offset = phy_addr - aligned_phy_addr;
 
   if (offset & 0x3) {
-    HANTRO_LOG(HANTRO_LEVEL_ERROR, "phy address 0x%llx unmappable\n", phy_addr);
+    HANTRO_LOG(HANTRO_LEVEL_ERROR, "phy address 0x%"PRIx64" unmappable\n", phy_addr);
     return NULL;
   }
-  v_addr = mmap(0, size + offset, PROT_READ | PROT_WRITE, MAP_SHARED, fd,
-                aligned_phy_addr);
+  v_addr = mmap(0, size + offset, PROT_READ | PROT_WRITE, MAP_SHARED, fd, aligned_phy_addr);
   if (v_addr == MAP_FAILED) {
     HANTRO_LOG(HANTRO_LEVEL_ERROR,
                "mmap_phy_addr: Failed to mmap phy Address! mmap size %d, phy "
-               "address 0x%llx\n",
-               size, phy_addr);
+               "address 0x%"PRIx64", error %s\n",
+               size, phy_addr, strerror(errno));
     return NULL;
   }
   return (uint32_t *)(v_addr + offset);
@@ -344,7 +344,7 @@ uint32_t *mmap_phy_addr_daemon(int32_t fd, vpu_addr_t phy_addr, int32_t size) {
  */
 void unmap_phy_addr_daemon(uint32_t *v_addr, int32_t size) {
   int ret;
-  void *p_aligned = (void *)(((uint64_t)v_addr) & (~(MEM_PAGE_SIZE - 1)));
+  void *p_aligned = (void *)(((uint64_t)v_addr) & (~(sysconf(_SC_PAGE_SIZE) - 1)));
 
   ret = munmap(p_aligned, size + ((void *)v_addr - p_aligned));
   ASSERT(0 == ret);
