@@ -108,7 +108,7 @@ enum
 typedef struct
 {
   TSM_TIMESTAMP ts;
-  unsigned long long age;
+  uint64_t age;
   void *key;
 } TSMControl;
 
@@ -155,7 +155,7 @@ typedef struct _TSManager
   TSM_TIMESTAMP dur_history_total;
   TSM_TIMESTAMP dur_history_buf[TSM_HISTORY_SIZE];
   TSMControl *ts_buf;
-  unsigned long long age;
+  uint64_t age;
   int tx_cnt;
   int rx_cnt;
   int cnt;
@@ -406,7 +406,7 @@ _TSManagerSend2 (void *handle, void *key, int send)
   int i;
   int index = -1;
   TSM_TIMESTAMP ts0 = 0, tstmp = TSM_TIMESTAMP_NONE;
-  unsigned long long age = 0;
+  uint64_t age = 0;
   TSM_TIMESTAMP half_interval;
 
   if (tsm) {
