@@ -421,6 +421,23 @@ static v4l2_inst_dec_event vsi_dec_handle_output_buffer(
     h->dec_info.frame_width = buf->output_width;
     h->dec_info.frame_height = buf->output_height;
   }
+  if (h->dec_last_pic_reschange) {
+    vsi_v4l2_msg msg = {0};
+
+    msg.error = 0;
+    msg.seq_id = NO_RESPONSE_SEQID;
+    msg.size = sizeof(v4l2_daemon_dec_buffers);
+    msg.cmd_id = V4L2_DAEMON_VIDIOC_BUF_RDY;
+    msg.inst_id = h->instance_id;
+    msg.params.dec_params.io_buffer.inbufidx = INVALID_IOBUFF_IDX;
+    msg.params.dec_params.io_buffer.outbufidx = index;
+    msg.params.dec_params.io_buffer.OutBufSize = buf->OutBufSize;
+    msg.params.dec_params.io_buffer.bytesused = 0;
+    send_notif_to_v4l2(pipe_fd, &msg, sizeof(struct vsi_v4l2_msg_hdr) +
+                                        sizeof(struct v4l2_daemon_dec_buffers));
+    h->dec_last_pic_reschange = 0;
+    return DEC_EMPTY_EVENT;
+  }
 
   dpb_receive_buffer(h, index, buf);
 
@@ -1527,6 +1544,7 @@ int vsi_dec_capture_setup2(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
   // it.
   vsi_dec_flush_output(h, v4l2_msg);
   h->dec_add_buffer_allowed = 1;
+  h->dec_last_pic_reschange = 0;
   h->dec_capture_state = DAEMON_QUEUE_STATE_OFF;
   h->dec_output_state = DAEMON_QUEUE_STATE_PAUSE;
   return 0;
@@ -1561,6 +1579,7 @@ int vsi_dec_capture_setup4(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
   ASSERT(h->dec_cur_state == DAEMON_DEC_STATE_CAPTURE_SETUP);
   vsi_dec_flush_output(h, v4l2_msg);
   h->dec_add_buffer_allowed = 1;
+  h->dec_last_pic_reschange = 0;
   if (h->dec_output_state == DAEMON_QUEUE_STATE_PEND_OFF) {
     h->dec_output_state2 = 1;
   }
@@ -1735,6 +1754,7 @@ int vsi_dec_seek3(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
 int vsi_dec_seek4(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
   ASSERT(h->dec_cur_state == DAEMON_DEC_STATE_SEEK);
   h->dec_add_buffer_allowed = 1;
+  h->dec_last_pic_reschange = 0;
   h->dec_capture_state = DAEMON_QUEUE_STATE_OFF;
   h->dec_capture_act = DAEMON_QUEUE_ACT_DROP;
   vsi_dec_flush_output(h, v4l2_msg);
@@ -1794,6 +1814,8 @@ int vsi_dec_reschange0(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
 int vsi_dec_reschange1(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
   ASSERT(h->dec_cur_state == DAEMON_DEC_STATE_SOURCE_CHANGE);
 
+  if (vsi_dec_dequeue_empty_pic(h))
+    h->dec_last_pic_reschange = 1;
   // vsi_dec_flush_output(h, v4l2_msg);
   h->dec_add_buffer_allowed = 0;
   h->dec_capture_state = DAEMON_QUEUE_STATE_OFF;
