@@ -62,7 +62,7 @@ v4l2_inst_dec_event h264_dec_seek(v4l2_dec_inst* h, vsi_v4l2_msg* v4l2_msg);
 static int h264_dec_release_pic(v4l2_dec_inst* h, void* pic) {
   H264DecRet ret;
   ASSERT(pic);
-  HANTRO_LOG(HANTRO_LEVEL_INFO, "H264DecPictureConsumed  bus address: %lx\n",
+  HANTRO_LOG(HANTRO_LEVEL_INFO, "H264DecPictureConsumed  bus address: %"PRIx64"\n",
              ((H264DecPicture*)pic)->output_picture_bus_address);
   ret = H264DecPictureConsumed(h->decoder_inst, (H264DecPicture*)pic);
 
@@ -89,7 +89,7 @@ static int h264_dec_add_buffer(v4l2_dec_inst* h, struct DWLLinearMem* mem_obj) {
     HANTRO_LOG(HANTRO_LEVEL_INFO, "H264DecAddBuffer rv = %d, %p, %p\n", rv,
                h->decoder_inst, mem_obj);
     if (rv == H264DEC_PARAM_ERROR) {
-      HANTRO_LOG(HANTRO_LEVEL_ERROR, "Inst[%lx]: Buffer is too small!\n",
+      HANTRO_LOG(HANTRO_LEVEL_ERROR, "Inst[%"PRIx64"]: Buffer is too small!\n",
             h->instance_id);
     }
   }
@@ -113,7 +113,7 @@ static void h264_dec_add_external_buffer(v4l2_dec_inst* h) {
     if (mem) {
       rv = H264DecAddBuffer(h->decoder_inst, mem);
       HANTRO_LOG(HANTRO_LEVEL_INFO,
-                 "H264DecAddBuffer rv = %d, %p, %p bus address: %lx\n", rv,
+                 "H264DecAddBuffer rv = %d, %p, %p bus address: %"PRIx64"\n", rv,
                  h->decoder_inst, mem, mem->bus_address);
     }
   }
@@ -369,7 +369,7 @@ v4l2_inst_dec_event h264_dec_decode(v4l2_dec_inst* h, vsi_v4l2_msg* v4l2_msg) {
   dec_input.data_len = in_mem->logical_size;
   dec_input.pic_id = h->dec_in_pic_id; /*curr_pic_id*/
 
-  HANTRO_LOG(HANTRO_LEVEL_INFO, "input: %p %lx stream len: %d\n",
+  HANTRO_LOG(HANTRO_LEVEL_INFO, "input: %p %"PRIx64" stream len: %d\n",
              dec_input.stream, dec_input.stream_bus_address,
              dec_input.data_len);
 
