@@ -47,6 +47,7 @@
 #define MCU_MAX_COUNT (8100)
 typedef struct {
   struct DWLLinearMem mem_obj[MAX_BUFFER_NUM];
+  uint32_t pic_id[MAX_BUFFER_NUM];
   int head;
   int tail;
 } JpegBufferQueue;
@@ -103,17 +104,21 @@ static u32 jpeg_is_empty_buf_queue(JpegBufferQueue *buf_q) {
 }
 
 static int jpeg_buf_enqueue(JpegBufferQueue *buf_q,
-                            struct DWLLinearMem *out_buffer) {
+                            struct DWLLinearMem *out_buffer,
+                            uint32_t pic_id) {
   if (jpeg_is_full_buf_queue(buf_q) == TRUE) return -1;
   memcpy(&buf_q->mem_obj[buf_q->head], out_buffer, sizeof(struct DWLLinearMem));
+  buf_q->pic_id[buf_q->head] = pic_id;
   buf_q->head = (buf_q->head + 1) % MAX_BUFFER_NUM;
   return 0;
 }
 
 static int jpeg_buffer_dequeue(JpegBufferQueue *buf_q,
-                               struct DWLLinearMem **display_mem) {
+                               struct DWLLinearMem **display_mem,
+                               uint32_t *pic_id) {
   if (jpeg_is_empty_buf_queue(buf_q) == TRUE) return -1;
   *display_mem = &buf_q->mem_obj[buf_q->tail];
+  if(pic_id != NULL) *pic_id = buf_q->pic_id[buf_q->tail];
   buf_q->tail = (buf_q->tail + 1) % MAX_BUFFER_NUM;
   return 0;
 }
@@ -170,8 +175,8 @@ static int jpeg_dec_release_pic(v4l2_dec_inst *h, void *pic) {
   if (pic) {
     rv = jpeg_buf_enqueue(
         &((JpegDecPrivData *)h->priv_data)->out_buffer_for_decoding,
-        (struct DWLLinearMem *)pic);
-    HANTRO_LOG(HANTRO_LEVEL_INFO, "Jpeg Dec Consumed  bus address: %lx\n",
+        (struct DWLLinearMem *)pic, 0);
+    HANTRO_LOG(HANTRO_LEVEL_INFO, "Jpeg Dec Consumed  bus address: %"PRIx64"\n",
                ((struct DWLLinearMem *)pic)->bus_address);
   }
   return rv;
@@ -179,7 +184,7 @@ static int jpeg_dec_release_pic(v4l2_dec_inst *h, void *pic) {
 
 static int jpeg_dec_remove_buffer(v4l2_dec_inst* h) {
   struct DWLLinearMem *mem = NULL;
-  while(jpeg_buffer_dequeue(&((JpegDecPrivData *)h->priv_data)->out_buffer_for_decoding, &mem) == 0) ;
+  while(jpeg_buffer_dequeue(&((JpegDecPrivData *)h->priv_data)->out_buffer_for_decoding, &mem, NULL) == 0) ;
   HANTRO_LOG(HANTRO_LEVEL_INFO, "finish\n");
   return 0;
 }
@@ -193,7 +198,7 @@ static int jpeg_dec_add_buffer(v4l2_dec_inst *h, struct DWLLinearMem *mem_obj) {
   int rv = -1;
   if (mem_obj) {
     rv = jpeg_buf_enqueue(
-        &((JpegDecPrivData *)h->priv_data)->out_buffer_for_decoding, mem_obj);
+        &((JpegDecPrivData *)h->priv_data)->out_buffer_for_decoding, mem_obj, 0);
     HANTRO_LOG(HANTRO_LEVEL_INFO, "JpegDecAddBuffer rv = %d, %p\n", rv,
                mem_obj);
   }
@@ -223,12 +228,16 @@ static int jpeg_dec_get_pic(v4l2_dec_inst *h,
   int mem_ret = 0;
   struct DWLLinearMem *display_mem = NULL;
   JpegDecPrivData *jpeg_priv_data = (JpegDecPrivData *)h->priv_data;
+  uint32_t pic_id = 0;
+
   mem_ret = jpeg_buffer_dequeue(&jpeg_priv_data->out_buffer_for_dequeue,
-                                &display_mem);
+                                &display_mem, &pic_id);
   if (mem_ret == -1) return -1;
   JpegDecImageInfo img_info = jpeg_priv_data->jpg_img_info;
   u32 chroma_size = jpeg_get_chroma_size(&img_info);
   ASSERT(display_mem);
+
+  dec_pic_info->pic_id = pic_id;
   dec_pic_info->priv_pic_data = display_mem;
   dec_pic_info->pic_width = h->dec_info.frame_width;
   dec_pic_info->pic_height = h->dec_info.frame_height;
@@ -471,12 +480,12 @@ v4l2_inst_dec_event jpeg_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
   }
 
   if (jpeg_buffer_dequeue(&jpeg_priv_data->out_buffer_for_decoding,
-                          &out_buffer) == -1) {
+                          &out_buffer, NULL) == -1) {
     ASSERT(0);
   }
 
   jpeg_set_dec_output_addr(&dec_input, out_buffer, &image_info, slice_index);
-  HANTRO_LOG(HANTRO_LEVEL_INFO, "input: %p %lx stream len: %d\n",
+  HANTRO_LOG(HANTRO_LEVEL_INFO, "input: %p %"PRIx64" stream len: %d\n",
              dec_input.stream_buffer.virtual_address,
              dec_input.stream_buffer.bus_address, dec_input.stream_length);
 
@@ -495,12 +504,10 @@ v4l2_inst_dec_event jpeg_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
         ret = JPEGDEC_FRAME_READY;
 
       case JPEGDEC_FRAME_READY:
-        jpeg_buf_enqueue(&jpeg_priv_data->out_buffer_for_dequeue, out_buffer);
+        jpeg_buf_enqueue(&jpeg_priv_data->out_buffer_for_dequeue, out_buffer, h->dec_in_pic_id);
         h->dec_pic_id++;
-#ifdef NXP_TIMESTAMP_MANAGER
         re_dec_event = DEC_PIC_DECODED_EVENT;
         h->consumed_len += dec_input.stream_length;
-#endif
         break;
 
       case JPEGDEC_SLICE_READY:
