@@ -61,7 +61,7 @@ typedef struct { u32 field_status; } mpeg4_dec_priv_data;
 static int mpeg4_dec_release_pic(v4l2_dec_inst *h, void *pic) {
   MP4DecRet ret;
   ASSERT(pic);
-  HANTRO_LOG(HANTRO_LEVEL_INFO, "MP4DecPictureConsumed  bus address: %lx\n",
+  HANTRO_LOG(HANTRO_LEVEL_INFO, "MP4DecPictureConsumed  bus address: %"PRIx64"\n",
              ((MP4DecPicture *)pic)->output_picture_bus_address);
   ret = MP4DecPictureConsumed(h->decoder_inst, (MP4DecPicture *)pic);
 
@@ -88,7 +88,7 @@ static int mpeg4_dec_add_buffer(v4l2_dec_inst *h,
     HANTRO_LOG(HANTRO_LEVEL_INFO, "MP4DecAddBuffer rv = %d, %p, %p\n", rv,
                h->decoder_inst, mem_obj);
     if (rv == MP4DEC_PARAM_ERROR) {
-      HANTRO_LOG(HANTRO_LEVEL_ERROR, "Inst[%lx]: Buffer is too small!\n",
+      HANTRO_LOG(HANTRO_LEVEL_ERROR, "Inst[%"PRIx64"]: Buffer is too small!\n",
             h->instance_id);
     }
   }
@@ -333,7 +333,7 @@ v4l2_inst_dec_event mpeg4_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
   dec_input.data_len = in_mem->logical_size;
   dec_input.pic_id = h->dec_in_pic_id; /*curr_pic_id*/
 
-  HANTRO_LOG(HANTRO_LEVEL_INFO, "input: %p %lx stream len: %d\n",
+  HANTRO_LOG(HANTRO_LEVEL_INFO, "input: %p %"PRIx64" stream len: %d\n",
              dec_input.stream, dec_input.stream_bus_address,
              dec_input.data_len);
 
