@@ -214,7 +214,7 @@ static void rv_dec_init_raw_mode(v4l2_dec_inst *h) {
 static int rv_dec_release_pic(v4l2_dec_inst *h, void *pic) {
   RvDecRet ret;
   ASSERT(pic);
-  HANTRO_LOG(HANTRO_LEVEL_INFO, "rvDecPictureConsumed  bus address: %lx\n",
+  HANTRO_LOG(HANTRO_LEVEL_INFO, "rvDecPictureConsumed  bus address: %"PRIx64"\n",
              ((RvDecPicture *)pic)->output_picture_bus_address);
   ret = RvDecPictureConsumed(h->decoder_inst, (RvDecPicture *)pic);
   ASSERT(ret == RVDEC_OK);
@@ -240,7 +240,7 @@ static int rv_dec_add_buffer(v4l2_dec_inst *h, struct DWLLinearMem *mem_obj) {
     HANTRO_LOG(HANTRO_LEVEL_INFO, "RvDecAddBuffer rv = %d, %p, %p\n", rv,
                h->decoder_inst, mem_obj);
     if (rv == RVDEC_PARAM_ERROR) {
-      HANTRO_LOG(HANTRO_LEVEL_ERROR, "Inst[%lx]: Buffer is too small!\n",
+      HANTRO_LOG(HANTRO_LEVEL_ERROR, "Inst[%"PRIx64"]: Buffer is too small!\n",
             h->instance_id);
     }
   }
@@ -279,7 +279,7 @@ static int rv_dec_get_pic(v4l2_dec_inst *h, vsi_v4l2_dec_picture *dec_pic_info,
 
   RvDecGetInfo(h->decoder_inst, &dec_info);
   dec_pic_info->priv_pic_data = h->priv_pic_data;
-  dec_pic_info->pic_id = dec_picture->pic_id;
+  dec_pic_info->pic_id = dec_picture->decode_id;
 
   dec_pic_info->pic_width = dec_picture->frame_width;
   dec_pic_info->pic_height = dec_picture->frame_height;
@@ -473,9 +473,9 @@ v4l2_inst_dec_event rv_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
       (rv_priv->stream_mode == RV_MODE) ? rv_priv->slice_info : NULL;
 
   dec_input.skip_non_reference = skip_non_reference;
-  dec_input.pic_id = h->dec_pic_id;
+  dec_input.pic_id = h->dec_in_pic_id;
 
-  HANTRO_LOG(HANTRO_LEVEL_INFO, "input: %p %lx stream len: %d\n",
+  HANTRO_LOG(HANTRO_LEVEL_INFO, "input: %p %"PRIx64" stream len: %d\n",
              dec_input.stream, dec_input.stream_bus_address,
              dec_input.data_len);
   do {
