@@ -141,7 +141,7 @@ static int vp9_dec_add_buffer(v4l2_dec_inst *h, struct DWLLinearMem *mem_obj) {
     HANTRO_LOG(HANTRO_LEVEL_INFO, "Vp9DecAddBuffer rv = %d, %p, %p\n", rv,
                h->decoder_inst, mem_obj);
     if (rv == DEC_PARAM_ERROR) {
-      HANTRO_LOG(HANTRO_LEVEL_ERROR, "Inst[%lx]: Buffer is too small!\n",
+      HANTRO_LOG(HANTRO_LEVEL_ERROR, "Inst[%"PRIx64"]: Buffer is too small!\n",
             h->instance_id);
     }
   }
