@@ -81,7 +81,7 @@ typedef struct {
 
 struct _v4l2_enc_inst {
   v4l2_daemon_inst* handler;
-  unsigned long instance_id;
+  uint64_t instance_id;
 
   const void* inst;
   v4l2_inst_state state;
