@@ -283,6 +283,29 @@ static int init_encoder_h264(v4l2_enc_inst *h,
       send_warning_orphan_msg(h->instance_id, WARN_LEVEL);
   }
 
+  /* update profile according to driver setting */
+  switch(enc_params->specific.enc_h26x_cmd.profile){
+    /* VCENC_H264_BASE_PROFILE */
+    case 9:
+      cfg->profile = 66;
+      break;
+    /* VCENC_H264_MAIN_PROFILE */
+    case 10:
+      cfg->profile = 77;
+      break;
+    /* VCENC_H264_HIGH_PROFILE */
+    case 11:
+      cfg->profile = 100;
+      break;
+    /* VCENC_H264_HIGH_10_PROFILE */
+    case 12:
+      cfg->profile = 110;
+      break;
+    default:
+      cfg->profile = 66;
+      break;
+  }
+
   /* Find the max number of reference frame */
   if (enc_params->specific.enc_h26x_cmd.intraPicRate == 1)
     cfg->refFrameAmount = 1;
@@ -673,8 +696,8 @@ static int set_coding_control_h264(v4l2_enc_inst *h,
   codingCfg->idrHeader = enc_params->specific.enc_h26x_cmd.idrHdr;
   if (enc_params->specific.enc_h26x_cmd.sliceSize != -1)
     codingCfg->sliceSize = enc_params->specific.enc_h26x_cmd.sliceSize;
-  if (enc_params->specific.enc_h26x_cmd.enableCabac != -1)
-    codingCfg->enableCabac = enc_params->specific.enc_h26x_cmd.enableCabac;
+  //if (enc_params->specific.enc_h26x_cmd.enableCabac != -1)
+  //  codingCfg->enableCabac = enc_params->specific.enc_h26x_cmd.enableCabac;
   codingCfg->videoFullRange = 0;
   if (enc_params->specific.enc_h26x_cmd.videoRange != -1)
     codingCfg->videoFullRange = enc_params->specific.enc_h26x_cmd.videoRange;
